.. _tutorials:

Tutorials
=========

This section contains a variety of tutorials related to the Axelrod library.

Contents:

.. toctree::
   :maxdepth: 2

   new_to_game_theory_and_or_python/index.rst
   running_axelrods_first_tournament/index.rst
   creating_heterogenous_player_moran_process/index.rst
   implement_new_games/index.rst
